(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global.lcg = factory());
}(this, (function () { 'use strict';

  /**
   * Increment used as default for the linear congruential generator.
   * @see https://en.wikipedia.org/wiki/Linear_congruential_generator
   * @type {number}
   */
  var INCREMENT = 12345;

  /**
   * Multiplier used as default for the linear congruential generator.
   * @see https://en.wikipedia.org/wiki/Linear_congruential_generator
   * @type {number}
   */
  var MULTIPLIER = 1103515245;

  /**
   * Modulus used as default for the linear congruential generator.
   * @see https://en.wikipedia.org/wiki/Linear_congruential_generator
   * @type {number}
   */
  var MODULUS = 2147483648;

  /**
   * Generates a new value based on its current `value`, `increment`, `multiplier` and `modulus`.
   *
   * @param {number} value - Current value
   * @param {number} [increment=INCREMENT] - Increment
   * @param {number} [multiplier=MULTIPLIER] - Multiplier 
   * @param {number} [modulus=MODULUS] - Modulus 
   * @returns {number} - Pseudo-random number
   */
  function linearCongruentialGenerator(value) {
    var increment = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : INCREMENT;
    var multiplier = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : MULTIPLIER;
    var modulus = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : MODULUS;

    return (value * multiplier + increment) % modulus;
  }

  var linearCongruentialGenerator$1 = {
    INCREMENT: INCREMENT,
    MULTIPLIER: MULTIPLIER,
    MODULUS: MODULUS,
    linearCongruentialGenerator: linearCongruentialGenerator
  };

  /**
   * Returns a function that generates a pseudo-random number.
   *
   * @param {number} [initialValue=0] - Initial value (also called seed)
   * @returns {Function} - Returns a function that generates pseudo-random numbers based on its initial value
   */
  function createRandomFunction() {
    var initialValue = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    var linearCongruentialGenerator = linearCongruentialGenerator$1.linearCongruentialGenerator,
        MODULUS = linearCongruentialGenerator$1.MODULUS;


    var currentValue = initialValue;

    /**
     * Returns a pseudo-random number.
     *
     * @returns {number} - Returns a value between 0.0 and 1.0 
     */
    return function () {
      currentValue = linearCongruentialGenerator(currentValue);
      return currentValue / MODULUS;
    };
  }

  return createRandomFunction;

})));
